@@ -665,7 +665,7 @@ void display_multiply(void)
 		snprintf(buf, sizeof(buf), "XX");
 	else	
 		snprintf(buf, sizeof(buf), "X%d", gi_bonus_multiply >> 1);
-	gfx_draw_text(buf, 800 - 48, 480 - 24, 0);
+	gfx_draw_text(buf, 800 - 2*SMALL_FONT_WIDTH, 480 - SMALL_FONT_HEIGHT - 4, 0);
 }
 
 void display_time(float num)
